feijoa package
==============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   feijoa.importance
   feijoa.jobs
   feijoa.models
   feijoa.search
   feijoa.storages
   feijoa.utils
   feijoa.visualization

Submodules
----------

feijoa.exceptions module
------------------------

.. automodule:: feijoa.exceptions
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: feijoa
   :members:
   :undoc-members:
   :show-inheritance:
